Module io_util
Source - input
- get input with the given output, similar to how input function works in python
- input_optional_repeat
- input, if user just press enter, then return default, otherwise
repeat until user gets the correct input
- input_other
- input with the given type, crashes if failed to convert
- input_other_or
- get input or if failed then return with the default value
- input_other_or_else
- get input or if failed then return with the default value
- input_other_repeat
- repeat forever until the user gets the correct input
- input_trim